@@ -3,8 +3,8 @@ import re
 import io
 import base64
 import requests
+from configparser import ConfigParser
 from os.path import join, dirname, isfile
-from dotenv import load_dotenv, set_key, unset_key, get_key
 
 import torch
 from torch.utils import model_zoo
@@ -13,15 +13,23 @@ from .loggers import Logger
 from .settings import TEMP_DIR, ME_URL, CLIENTS_URL, MODELS_URL, JOBS_URL, SUBMISSIONS_URL, DATA_URL, BASE_URL
 from .settings import system_info
 
-# Load environment variables
-env_file = join(dirname(os.path.realpath(__file__)), '.env')  # New .env file
-load_dotenv(dotenv_path=env_file)
+# Load configuration parameters.
+# This includes a simple token authentication encoded in base64
+config_file = join(dirname(os.path.realpath(__file__)), 'config.ini')  # New .env file
+config = ConfigParser()
+config.read(config_file)
 
 # Create a Logger
 logger = Logger()
 logger.info(system_info())
 
 
+def update_config():
+    """Update the configuration file."""
+    with open(config_file, 'w') as cf:
+        config.write(cf)
+
+
 def login(username, password):
     """
     Loging in to the FEDBIONET API.
@@ -31,26 +39,29 @@ def login(username, password):
     """
     res = requests.get(ME_URL, auth=(username, password))
     if res.status_code == 200:
+        "Save token to disk and return user profile data."
+
         TOKEN = base64.b64encode(f'{username}:{password}'.encode()).decode()
-        if not isfile(env_file):
-            open(env_file, 'w')
+        config['DEFAULT']['TOKEN'] = TOKEN
+        update_config()
 
-        set_key(env_file, 'FEDBIONET_TOKEN', TOKEN)
         return res.json()
     elif res.status_code in range(400, 500):
+        "Not authorized code."
+        logger.error(f'Login failed: {res.content}')
         return res.json()
     else:
         raise ConnectionError('Connection seems not to be working')
 
 
 def get_auth():
-    TOKEN = get_key(env_file, 'FEDBIONET_TOKEN')
+    TOKEN = config['DEFAULT']['TOKEN']
     return tuple(base64.b64decode(TOKEN.encode()).decode().split(':'))
 
 
 def logout():
-    unset_key(env_file, 'FEDBIONET_TOKEN')
-    load_dotenv(dotenv_path=env_file)
+    config.remove_option('DEFAULT', 'TOKEN')
+    update_config()
 
 
 def is_logged_in():
@@ -213,3 +224,9 @@ def load_base_model(job_url):
 
     # Download file and return model file path
     return load_model_from_url(json['model_file'])
+
+
+def get_models():
+    """Get a list of the currently available models."""
+    logger.debug('Getting a list of models.')
+    return get(MODELS_URL)
